---@meta

---@class _.lspconfig.settings.sqlls.SqlLanguageServer
---connection setting
---
---```lua
---default = {}
---```
---@field connections? any[]
---lint setting
---
---```lua
---default = {}
---```
---@field lint? table

---@class lspconfig.settings.sqlls
---@field sqlLanguageServer? _.lspconfig.settings.sqlls.SqlLanguageServer
